mobspy.plot_params package — MobsPy 2.2 documentation

# mobspy.plot_params package

## Submodules

## mobspy.plot_params.default_plot_reader module

mobspy.plot_params.default_plot_reader.get_default_plot_parameters()

## mobspy.plot_params.example_plot_reader module

This model is responsible for storing example plotting parameters It’s used by the simulation to check which parameters exist or not

mobspy.plot_params.example_plot_reader.get_example_plot_parameters()

## Module contents